==> viha-5.15.tar.gz: viha-5.15/tilanne-kalusto.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Kaluston tilanne</title>
</head>
" . body_bgcolor() . "
";

$now = date('Y-m-d H:i:s');

echo "<h1>" . ota_paivystys_nimi() . ", kaluston tilanne, $now</h1>\n";

taktiset_linkit();

echo "<p>Viestivlineet\n";

$sql =
  "SELECT laite.id,jarjesto_id,hlo_id,laite,tunniste,laite.selite,verkko,kutsu,
          merkitty,vakuutettu,vara_akut,laite_tyyppi,palaute,lisavarusteet,
          jarjesto.jarjesto,laite.ts
   FROM laite,verkko,ryhma,laite_tyyppi,jarjesto
   WHERE laite.verkko_id = verkko.id AND laite.ryhma_id = ryhma.id
         AND laite.laite_tyyppi_id = laite_tyyppi.id
         AND laite.jarjesto_id = jarjesto.id
         AND laite.paivystys_id = " . s("paivystys") . "
   ORDER BY verkko,laite_tyyppi,laite,tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<table border=1>\n";
  echo tr_bgcolor()
    . "<th>Verkko"
    . "<th>Tyyppi"
    . "<th>Muutettu"
    . "<th>Jrjest"
    . "<th>Henkil"
    . "<th>Laite"
    . "<th>Tunn"
    . "<th>Selite"
    . "<th>Ryhm"
    . "<th>Merk"
    . "<th>Vak"
    . "<th>V.akut"
    . "<th>List"
    . "<th>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    $a_id = $a['id'];
    echo "<tr>",
      "<TD>$a[verkko]",
      "<TD>$a[laite_tyyppi]",
      "<TD align=right>" . vain_hhmm($a['ts']),
      "<TD>$a[jarjesto]",
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>$a[laite]",
      "<TD>$a[tunniste]",
      "<TD>$a[selite]",
      "<TD>$a[kutsu]",
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$a[vara_akut]",
      "<TD>$a[lisavarusteet]",
      "<TD>$a[palaute]";
  }
  echo "</table>\n";
 } else {
  echo "<P>Plop. Ei viestivlinetietoja.";
 }

echo "<p>Muu kalusto\n";

$sql =
  "SELECT tavara.id,jarjesto_id,hlo_id,tavara,tunniste,tavara.selite,kutsu,
          merkitty,vakuutettu,tavara_tyyppi,palaute,jarjesto.jarjesto,tavara.ts
   FROM tavara,ryhma,tavara_tyyppi,jarjesto
   WHERE tavara.ryhma_id = ryhma.id
         AND tavara.tavara_tyyppi_id = tavara_tyyppi.id
         AND tavara.jarjesto_id = jarjesto.id
         AND (tavara.paivystys_id = " . s("paivystys") . ")
   ORDER BY tavara_tyyppi,tavara,tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<table border=1>\n";
  echo tr_bgcolor()
    . "<th>Tyyppi"
    . "<th>Muutettu"
    . "<th>Jrjest"
    . "<th>Henkil"
    . "<th>Tavara"
    . "<th>Tunn"
    . "<th>Selite"
    . "<th>Ryhm"
    . "<th>Merk"
    . "<th>Vak"
    . "<th>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    $a_id = $a['id'];
    echo "<tr>",
      "<TD>$a[tavara_tyyppi]",
      "<TD align=right>" . vain_hhmm($a['ts']),
      "<TD>$a[jarjesto]",
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>$a[tavara]",
      "<TD>$a[tunniste]",
      "<TD>$a[selite]",
      "<TD>$a[kutsu]",
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$a[palaute]";
  }
  echo "</table>\n";
 } else {
  echo "<P>Plop. Ei tavaratietoja.";
 }

loppu();

?>

</body> 
</html>

<!-- RCS $Id: tilanne-kalusto.php,v 1.16 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tilanne-kalusto.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$file = basename(__FILE__);

include "common.php";

echo "
<html>
<head>
 <title>VIHA - Kaluston tilanne</title>
</head>
" . body_bgcolor() . "
";

$now = date('Y-m-d H:i:s');

echo "<h1>" . muotoile_operaatio() . ", kaluston tilanne, $now</h1>\n";

taktiset_linkit();

echo "<p>Viestivlineet\n";

$sql =
  "SELECT laite.id,jarjesto_id,hlo_id,laite,tunniste,laite.selite,verkko,kutsu,
          merkitty,vakuutettu,vara_akut,laite_tyyppi,palaute,lisavarusteet,
          jarjesto.jarjesto,laite.ts
   FROM laite,verkko,ryhma,laite_tyyppi,jarjesto
   WHERE laite.verkko_id = verkko.id AND laite.ryhma_id = ryhma.id
         AND laite.laite_tyyppi_id = laite_tyyppi.id
         AND laite.jarjesto_id = jarjesto.id
         AND laite.paivystys_id = " . s("paivystys") . "
   ORDER BY verkko,laite_tyyppi,laite,tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<table border=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<th>Verkko"
    . "<th>Tyyppi"
    . "<th>Muutettu"
    . "<th>Jrjest"
    . "<th>Henkil"
    . "<th>Laite"
    . "<th>Tunn"
    . "<th>Selite"
    . "<th>Ryhm"
    . "<th>Merk"
    . "<th>Vak"
    . "<th>V.akut"
    . "<th>List"
    . "<th>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    $a_id = $a['id'];
    echo tr() . "",
      "<TD>$a[verkko]",
      "<TD>$a[laite_tyyppi]",
      "<TD align=right>" . vain_hhmm($a['ts']),
      "<TD>$a[jarjesto]",
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>$a[laite]",
      "<TD>$a[tunniste]",
      "<TD>$a[selite]",
      "<TD>$a[kutsu]",
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$a[vara_akut]",
      "<TD>$a[lisavarusteet]",
      "<TD>$a[palaute]";
  }
  echo "</table>\n";
 } else {
  echo "<P>Plop. Ei viestivlinetietoja.";
 }

echo "<p>Muu kalusto\n";

$sql =
  "SELECT tavara.id,jarjesto_id,hlo_id,tavara,tunniste,tavara.selite,kutsu,
          merkitty,vakuutettu,tavara_tyyppi,palaute,jarjesto.jarjesto,tavara.ts
   FROM tavara,ryhma,tavara_tyyppi,jarjesto
   WHERE tavara.ryhma_id = ryhma.id
         AND tavara.tavara_tyyppi_id = tavara_tyyppi.id
         AND tavara.jarjesto_id = jarjesto.id
         AND (tavara.paivystys_id = " . s("paivystys") . ")
   ORDER BY tavara_tyyppi,tavara,tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<table border=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<th>Tyyppi"
    . "<th>Muutettu"
    . "<th>Jrjest"
    . "<th>Henkil"
    . "<th>Tavara"
    . "<th>Tunn"
    . "<th>Selite"
    . "<th>Ryhm"
    . "<th>Merk"
    . "<th>Vak"
    . "<th>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    $a_id = $a['id'];
    echo tr() . "",
      "<TD>$a[tavara_tyyppi]",
      "<TD align=right>" . vain_hhmm($a['ts']),
      "<TD>$a[jarjesto]",
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>$a[tavara]",
      "<TD>$a[tunniste]",
      "<TD>$a[selite]",
      "<TD>$a[kutsu]",
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$a[palaute]";
  }
  echo "</table>\n";
 } else {
  echo "<P>Plop. Ei tavaratietoja.";
 }

loppu();

?>

</body> 
</html>

<!-- RCS $Id: tilanne-kalusto.php,v 1.18 2009/09/29 16:09:15 riku Exp $ -->
